using Barcode.Host.Shared.DataModels;
using Barcode.Host.Shared.Models.Stateless;
using Microsoft.AspNetCore.Mvc.Testing;
using Microsoft.Extensions.DependencyInjection;
using Serilog;

namespace Barcode.Host.Tests;

[TestClass]
public class UnitTestLastScanController
{

#pragma warning disable CS8618

    private static ILogger _Logger;
    private static string _ControllerName;
    private static TestContext _TestContext;
    private static WebApplicationFactory<Server.Program> _WebApplicationFactory;

#pragma warning restore

    [ClassInitialize]
    public static void ClassInitAsync(TestContext testContext)
    {
        _TestContext = testContext;
        _Logger = Log.ForContext<UnitTestLastScanController>();
        _WebApplicationFactory = new WebApplicationFactory<Server.Program>();
        _ControllerName = nameof(Server.ApiControllers.LastScanController)[..^10];
    }

    private static void NonThrowTryCatch()
    {
        try
        { throw new Exception(); }
        catch (Exception) { }
    }

    [TestMethod]
    public void TestControllerName()
    {
        _Logger.Information("Starting Web Application");
        Assert.AreEqual(ILastScanController<string>.GetRouteName(), _ControllerName);
        _Logger.Information($"{_TestContext?.TestName} completed");
        NonThrowTryCatch();
    }

#if DEBUG
    [Ignore]
#endif
    [TestMethod]
    public void GetScan()
    {
        _Logger.Information("Starting Web Application");
        IServiceProvider serviceProvider = _WebApplicationFactory.Services.CreateScope().ServiceProvider;
        ILastScanService lastScanService = serviceProvider.GetRequiredService<ILastScanService>();
        Result<string> result = lastScanService.GetScan();
        Assert.IsNotNull(result?.Results);
        _Logger.Information($"{_TestContext?.TestName} completed");
        NonThrowTryCatch();
    }

#if DEBUG
    [Ignore]
#endif
    [TestMethod]
    public async Task GetScanApi()
    {
        HttpClient httpClient = _WebApplicationFactory.CreateClient();
        _Logger.Information("Starting Web Application");
        string? json = await httpClient.GetStringAsync($"api/{_ControllerName}/O171927.1.37/");
        File.WriteAllText(Path.Combine(AppContext.BaseDirectory, $"{_ControllerName}-{nameof(GetScan)}.json"), json);
        Result<string>? result = System.Text.Json.JsonSerializer.Deserialize<Result<string>>(json);
        Assert.IsNotNull(result?.Results);
        _Logger.Information($"{_TestContext?.TestName} completed");
        NonThrowTryCatch();
    }

}